@@ -1,5 +1,5 @@
 package Parallel::ForkManager::Segmented;
-$Parallel::ForkManager::Segmented::VERSION = '0.4.0';
+$Parallel::ForkManager::Segmented::VERSION = '0.6.0';
 use strict;
 use warnings;
 use 5.014;
@@ -120,88 +120,37 @@ segments of items.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
-    #! /usr/bin/env perl
-
-    use strict;
-    use warnings;
-    use 5.014;
-    use Cwd ();
-
-    use WML_Frontends::Wml::Runner ();
     use Parallel::ForkManager::Segmented ();
+    use Path::Tiny qw/ path /;
 
-    my $UNCOND  = $ENV{UNCOND} // '';
-    my $CMD     = shift @ARGV;
-    my (@dests) = @ARGV;
+    my $NUM    = 30;
+    my $temp_d = Path::Tiny->tempdir;
 
-    my $PWD       = Cwd::getcwd();
-    my @WML_FLAGS = (
-        qq%
-    --passoption=2,-X3074 --passoption=2,-I../lib/ --passoption=3,-I../lib/
-    --passoption=3,-w -I../lib/ $ENV{LATEMP_WML_FLAGS} -p1-3,5,7 -DROOT~.
-    -DLATEMP_THEME=sf.org1 -I $HOME/apps/wml
-    % =~ /(\S+)/g
-    );
-
-    my $T2_SRC_DIR = 't2';
-    my $T2_DEST    = "dest/$T2_SRC_DIR";
-
-    chdir($T2_SRC_DIR);
-
-    my $obj = WML_Frontends::Wml::Runner->new;
-
-    sub is_newer
-    {
-        my $file1 = shift;
-        my $file2 = shift;
-        my @stat1 = stat($file1);
-        my @stat2 = stat($file2);
-        if ( !@stat2 )
-        {
-            return 1;
-        }
-        return ( $stat1[9] >= $stat2[9] );
-    }
-
-    my @queue;
-    foreach my $lfn (@dests)
-    {
-        my $dest     = "$T2_DEST/$lfn";
-        my $abs_dest = "$PWD/$dest";
-        my $src      = "$lfn.wml";
-        if ( $UNCOND or is_newer( $src, $abs_dest ) )
-        {
-            push @queue,
-            [
-                [ $abs_dest, "-DLATEMP_FILENAME=$lfn", $src, ],
-                $dest,
-            ];
-        }
-    }
-    my $to_proc = [ map $_->[1], @queue ];
-    my @FLAGS = ( @WML_FLAGS, '-o', );
-    my $proc = sub {
-        $obj->run_with_ARGV(
-            {
-                ARGV => [ @FLAGS, @{ shift(@_)->[0] } ],
-            }
-        ) and die "$!";
+    my @queue = ( 1 .. $NUM );
+    my $proc  = sub {
+        my $fn = shift;
+        $temp_d->child($fn)->spew_utf8("Wrote $fn .\n");
         return;
     };
     Parallel::ForkManager::Segmented->new->run(
         {
             WITH_PM      => 1,
             items        => \@queue,
-            nproc        => 4,
+            nproc        => 3,
             batch_size   => 8,
             process_item => $proc,
         }
     );
-    system("cd $PWD && $CMD @{$to_proc}") and die "$!";
+
+=head1 DESCRIPTION
+
+This module builds upon L<Parallel::ForkManager> allowing one to pass a
+batch (or "segment") of several items for processing inside a worker. This
+is done in order to hopefully reduce the forking/exiting overhead.
 
 =head1 METHODS
 
@@ -305,6 +254,18 @@ Example:
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Parallel::ForkManager>
+
+=item * L<IO::Async::Function> - a less snowflake approach.
+
+=item * L<https://perl-begin.org/uses/multitasking/>
+
+=back
+
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
